Welcome to ClientVPS Mirrors

Help for package gpx
Type: Package
Title: Process GPX Files into R Data Structures
Version: 1.1.0
Description: Process open standard GPX files into data.frames for further use and analysis in R.
License: MIT + file LICENSE
Encoding: UTF-8
Depends: R (≥ 4.0)
Imports: xml2, rvest, lubridate
Suggests: testthat
RoxygenNote: 7.1.2
NeedsCompilation: no
Packaged: 2021-11-08 16:04:49 UTC; mark
Author: Mark Ewing [aut, cre]
Maintainer: Mark Ewing <b.mark@ewingsonline.com>
Repository: CRAN
Date/Publication: 2021-11-08 16:40:02 UTC

Read a .gpx file into a data.frame

Description

Read a .gpx file into a list of data.frames, one each for tracks, routes and waypoints.

The named element 'tracks' is a named list of tracks present in the file. It will always contain columns for Elevation, Time, Latitude, Longitude, and Segment ID.

The named element 'routes' is an unnamed list of routes present in the file. It will always contain columns for Elevation, Time, Latitude, and Longitude.

The named element 'waypoints' is an unnamed list of routes present in the file. It will always contain columns for Elevation, Time, Latitude, and Longitude.

In each case, if there are extensions in the file within the record type, it will attempt to include them as columns as well. If there are no points of the specified type, it will contain a 0-row data.frame with all the standard column names.

Usage

read_gpx(file)

Arguments

file

A path to a .gpx file

Value

List of data frames

Examples

## Not run: 
hikes = read_gpx('hiking_file.gpx')
hikes$tracks
hikes$routes
hikes$waypoints

## End(Not run)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.